@@ -15,8 +15,7 @@ logger = logging.getLogger(__name__)
 
 
 class Ed_izmQuerySet(CommonManagetWithLookUpFieldsQuerySet):
-    def filter(self, *args, **kwargs):
-        return super().filter(*args, **kwargs)
+    pass
 
 
 class Ed_izmManager(CommonManagetWithLookUpFieldsManager):
