@@ -7,7 +7,7 @@ from django.db import transaction, connection
 from django.db.models import PositiveIntegerField, BigIntegerField, UniqueConstraint, Q
 from django.forms import model_to_dict
 
-from isc_common import setAttr, delAttr, get_list_nums_key_dict, delAttr1
+from isc_common import setAttr, delAttr, get_list_nums_key_dict
 from isc_common.auth.models.user import User
 from isc_common.bit import TurnBitOn
 from isc_common.common.functions import delete_dbl_spaces
@@ -33,20 +33,23 @@ class ItemQuerySet(CommonManagetWithLookUpFieldsQuerySet):
 
         res = super().create(**kwargs)
 
-        item = delAttr1(kwargs, 'id')
-        setAttr(item, 'operation', res)
-        setAttr(item, 'hcreator', res.creator)
-        Item_history.objects.create(**item)
+        delAttr(kwargs, 'id')
+        delAttr(kwargs, 'creator')
+        setAttr(kwargs, 'hcreator', res.creator)
+        setAttr(kwargs, 'item', res)
+        Item_history.objects.create(**kwargs)
         return res
 
     def update(self, **kwargs):
         from kaf_pas.ckk.models.item_history import Item_history
 
         res = super().update(**kwargs)
-        item = delAttr1(kwargs, 'id')
-        setAttr(item, 'operation', res)
-        setAttr(item, 'hcreator', res.creator)
-        Item_history.objects.create(**item)
+
+        delAttr(kwargs, 'id')
+        delAttr(kwargs, 'creator')
+        setAttr(kwargs, 'hcreator', res.creator)
+        setAttr(kwargs, 'item', res)
+        Item_history.objects.create(**kwargs)
         return res
 
 
