@@ -1,6 +1,6 @@
 import logging
 
-from django.db.models import BooleanField, PositiveIntegerField
+from django.db.models import BooleanField, PositiveIntegerField, DecimalField
 
 from isc_common import delAttr
 from isc_common.fields.name_field import NameField
@@ -8,11 +8,12 @@ from isc_common.fields.related import ForeignKeyProtect
 from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditQuerySet, AuditManager
 from isc_common.models.base_ref import Hierarcy
+from isc_common.number import DecimalToStr
 from kaf_pas.ckk.models.item import Item_add
 from kaf_pas.kd.models.document_attributes import Document_attributes
 from kaf_pas.kd.models.documents import Documents
 from kaf_pas.kd.models.lotsman_documents_hierarcy import Lotsman_documents_hierarcy
-from kaf_pas.planing.models.operations_view import Operations_view
+from kaf_pas.planing.models.operation_item_view import Operation_item_view
 
 logger = logging.getLogger(__name__)
 
@@ -25,11 +26,11 @@ class Item_flat_viewQuerySet(AuditQuerySet):
     def get_infoPlan(self, request, *args):
         request = DSRequest(request=request)
         data = request.get_data()
-        item_ids = [item.get('item_id') for item in Operations_view.objects.filter(
+        item_ids = [item.get('item_id') for item in Operation_item_view.objects.filter(
             launch_id=data.get('launch_id'),
-            operation_level_id=data.get('level_id'),
+            level_id=data.get('level_id'),
             resource_id=data.get('resource_id'),
-            resource__location_id=data.get('location_id'),
+            location_id=data.get('location_id'),
         ).values('item_id').distinct()]
 
         delAttr(request.json.get('data'), 'full_name')
@@ -49,23 +50,23 @@ class Item_flat_viewManager(AuditManager):
     @staticmethod
     def getRecord(record):
         res = {
-            'id': record.id,
-            'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
-            'STMP_1__value_str': record.STMP_1.value_str if record.STMP_1 else None,
-            'STMP_2_id': record.STMP_2.id if record.STMP_2 else None,
-            'STMP_2__value_str': record.STMP_2.value_str if record.STMP_2 else None,
-            'lastmodified': record.lastmodified,
-            'document_id': record.document.id if record.document else None,
-            'document__file_document': record.document.file_document if record.document else None,
-            'lotsman_document_id': record.lotsman_document.id if record.lotsman_document else None,
-            'editing': record.editing,
-            'deliting': record.deliting,
-            'isFolder': record.isFolder,
-            'relevant': record.relevant,
             'confirmed': record.confirmed,
-            'where_from': record.where_from,
-            'version': record.version,
+            'deliting': record.deliting,
+            'document__file_document': record.document.file_document if record.document else None,
+            'document_id': record.document.id if record.document else None,
+            'editing': record.editing,
+            'id': record.id,
+            'isFolder': record.isFolder,
+            'lastmodified': record.lastmodified,
+            'lotsman_document_id': record.lotsman_document.id if record.lotsman_document else None,
             'props': int(record.props),
+            'relevant': record.relevant,
+            'STMP_1__value_str': record.STMP_1.value_str if record.STMP_1 else None,
+            'STMP_1_id': record.STMP_1.id if record.STMP_1 else None,
+            'STMP_2__value_str': record.STMP_2.value_str if record.STMP_2 else None,
+            'STMP_2_id': record.STMP_2.id if record.STMP_2 else None,
+            'version': record.version,
+            'where_from': record.item.where_from,
         }
         # print(res)
         return res
