@@ -1,5 +1,6 @@
 import logging
 
+from django.conf import settings
 from django.db.models import BigIntegerField, BooleanField, PositiveIntegerField
 from django.forms import model_to_dict
 
@@ -12,6 +13,7 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.models.audit import AuditQuerySet, AuditManager
 from isc_common.models.base_ref import Hierarcy
 from isc_common.number import DelProps
+from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.item import Item_add, ItemManager, Item
 from kaf_pas.ckk.models.item_line import Item_lineManager
 from kaf_pas.ckk.models.item_refs import Item_refsManager, Item_refs
@@ -32,6 +34,17 @@ class Item_operations_viewQuerySet(AuditQuerySet):
 
 
 class Item_operations_viewManager(AuditManager):
+    @staticmethod
+    def refreshRows(ids):
+        if isinstance(ids, int):
+            ids = [ids]
+        records = [Item_operations_viewManager.getRecord(record) for record in Item_operations_view.objects.filter(id__in=ids)]
+        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_item_grid_row, records=records)
+
+    @staticmethod
+    def fullRows(suffix=''):
+        WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_order_item_grid}{suffix}')
+
     def updateFromRequest(self, request, removed=None, function=None):
         if not isinstance(request, DSRequest):
             request = DSRequest(request=request)
