@@ -41,10 +41,6 @@ class Item_refsQuerySet(AuditQuerySet):
                     Item_refs.objects1.create(child=item_refs.child, parent_id=int(audo_top_level))
             return super().delete()
 
-    def get_or_create(self, defaults=None, **kwargs):
-        return super().get_or_create(defaults=defaults, **kwargs)
-
-
 class Item_refsManager(AuditManager):
     @staticmethod
     def props():
@@ -72,15 +68,6 @@ class Item_refsManager(AuditManager):
 class Item_refs(Hierarcy):
     child = ForeignKeyProtect(Item, related_name='child')
     parent = ForeignKeyProtect(Item, related_name='parent', blank=True, null=True)
-
-    # def get_parent(self, parent, path_array):
-    #     path_array.append(parent.item_name)
-    #     self.get_parent(parent.parent)
-    #
-    # def full_path(self):
-    #     path_array = [self.child.item_name]
-    #     parent
-
     props = Item_refsManager.props()
 
     objects = TreeAuditModelManager()
