@@ -126,7 +126,7 @@ class Item_viewManager(TreeAuditModelManager):
         return Item_viewQuerySet(self.model, using=self._db)
 
     @staticmethod
-    def copy_item(item, parent_item):
+    def copy_item(item, parent_item, user):
         from kaf_pas.ckk.models.item_refs import Item_refs
         from kaf_pas.ckk.models.item_line import Item_line
         from kaf_pas.ckk.models.item_image_refs import Item_image_refs
@@ -141,6 +141,7 @@ class Item_viewManager(TreeAuditModelManager):
         delAttr(dict_item, 'relevant')
         delAttr(dict_item, 'where_from')
         delAttr(dict_item, 'isFolder')
+        setAttr(dict_item, 'user', user)
         setAttr(dict_item, 'STMP_1_id', dict_item.get('STMP_1'))
         setAttr(dict_item, 'STMP_2_id', dict_item.get('STMP_2'))
         setAttr(dict_item, 'document_id', dict_item.get('document'))
@@ -208,7 +209,7 @@ class Item_viewManager(TreeAuditModelManager):
             item = self.get(id=data.get('id'), parent_id=data.get('parent_id'))
             parent_item = Item.objects.get(id=data.get('parent_id'))
 
-            new_item = Item_viewManager.copy_item(item=item, parent_item=parent_item)
+            new_item = Item_viewManager.copy_item(item=item, parent_item=parent_item, user=request.user)
             res = model_to_dict(new_item)
             setAttr(res, 'props', res.get('props')._value)
 
