@@ -2,6 +2,7 @@ import logging
 
 from django.core.management import BaseCommand
 
+from isc_common.common.functions import delete_dbl_spaces
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.ckk.models.item_view import Item_view
 from kaf_pas.kd.models.documents_ext import DocumentManagerExt
@@ -15,4 +16,4 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         logger.info(self.help)
 
-        DocumentManagerExt(logger=logger).make_pdf(document=document, STMP_1_type=STMP_1_type, STMP_2_type=STMP_2_type)
+        print(delete_dbl_spaces('К4310М-243-1.10.20.660           СБ'))
