@@ -1,19 +1,21 @@
 import logging
 
 from isc_common import setAttr
-from kaf_pas.kd.models.document_attrs_view import Document_attrs_view, Document_attrs_viewQuerySet, Document_attrs_viewManager
+
+from kaf_pas.kd.models.document_attributes import Document_attributesQuerySet
+from kaf_pas.kd.models.document_attributes_view import Document_attributes_view, Document_attributes_viewManager
 
 logger = logging.getLogger(__name__)
 
 
-class Cdw_attrsQuerySet(Document_attrs_viewQuerySet):
+class Cdw_attrsQuerySet(Document_attributesQuerySet):
 
     def filter(self, *args, **kwargs):
         setAttr(kwargs, 'attr_type__code__contains', 'STMP')
         return super().filter(*args, **kwargs)
 
 
-class Cdw_attrsManager(Document_attrs_viewManager):
+class Cdw_attrsManager(Document_attributes_viewManager):
 
     def get_queryset(self):
         return Cdw_attrsQuerySet(self.model, using=self._db)
@@ -36,7 +38,7 @@ class Cdw_attrsManager(Document_attrs_viewManager):
         return res
 
 
-class Cdw_attrs(Document_attrs_view):
+class Cdw_attrs(Document_attributes_view):
     objects = Cdw_attrsManager()
 
     class Meta:
