@@ -35,8 +35,8 @@ class Document_attr_cross1QuerySet(QuerySet):
     def create(self, **kwargs):
         return super().create(**self._position_in_document(**kwargs))
 
-    def update(self, **kwargs):
-        return super().create(**self._position_in_document(**kwargs))
+    # def update(self, **kwargs):
+    #     return super().create(**self._position_in_document(**kwargs))
 
     def filter(self, *args, **kwargs):
         return super().filter(*args, **kwargs)
