@@ -103,10 +103,7 @@ class Lotsman_documents_hierarcyManager(AuditManager):
 
         Lotsman_documents_hierarcyManagerExt(
             user=request.user,
-            documentManagerExt=DocumentManagerExt(
-                logger=logger
-            )
-        ).make_items(lotsman_documents_hierarcy_view_record=Lotsman_documents_hierarcy_view.objects.get(id=data.get('id')))
+            documentManagerExt=DocumentManagerExt(logger=logger)).make_items(lotsman_documents_hierarcy_view_record=Lotsman_documents_hierarcy_view.objects.get(id=data.get('id')))
 
         return data
 
