@@ -3,7 +3,7 @@ import logging
 from django.core.management import BaseCommand
 
 from kaf_pas.planing.models.levels import Levels
-from kaf_pas.planing.models.routing import RoutingManager
+from kaf_pas.planing.models.rouning_ext import Route_item
 
 logger = logging.getLogger(__name__)
 
@@ -12,5 +12,6 @@ class Command(BaseCommand):
     def handle(self, *args, **options):
         for level in Levels.objects.all():
             print('\n\n')
-            for a in RoutingManager.make_resourcesLevel(launch_id=30, level_id=16, location_id=64):
+            route_item = Route_item()
+            for a in route_item.make_resourcesLevel(launch_id=30, level_id=16, location_id=64):
                 print(a)
