@@ -31,7 +31,7 @@ class Operation_launch_itemManager(AuditManager):
 class Operation_launch_item(AuditModel):
     operation = ForeignKeyCascade(Operations)
     launch_item = ForeignKeyCascade(Launch_operations_item)
-    operation_refs = ForeignKeyCascade(Operation_refs)
+    # operation_refs = ForeignKeyCascade(Operation_refs)
 
     objects = Operation_launch_itemManager()
 
