@@ -1,17 +1,14 @@
 import copy
 import logging
-from datetime import datetime
 
 from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
-from django.db import transaction, connection
+from django.db import transaction
 from django.db.models import DecimalField, DateTimeField, TextField, BooleanField, BigIntegerField, PositiveIntegerField
-from django.forms import model_to_dict
 
 from isc_common import setAttr, delAttr, NotImplement
 from isc_common.auth.models.user import User
-from isc_common.common import blinkString, red, restarted, new
-from isc_common.common.functions import ExecuteStoredProc
+from isc_common.common import blinkString, red
 from isc_common.datetime import DateTimeToStr
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.related import ForeignKeyProtect
@@ -19,13 +16,12 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_manager import CommonManager
 from isc_common.models.base_ref import Hierarcy
 from isc_common.number import DecimalToStr, ToDecimal
-from kaf_pas.ckk.models.ed_izm import Ed_izm
+from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.ckk.models.locations import Locations
 from kaf_pas.planing.models.operation_item_view import Operation_item_view
-from kaf_pas.planing.models.operation_launches import Operation_launches
 from kaf_pas.planing.models.operation_types import Operation_types
-from kaf_pas.planing.models.operations import OperationsManager, OperationsQuerySet, Operations
+from kaf_pas.planing.models.operations import OperationsQuerySet, Operations
 from kaf_pas.planing.models.production_ext import Production_ext
 from kaf_pas.planing.models.rouning_ext import Routing_ext
 from kaf_pas.production.models.launches import Launches
@@ -283,6 +279,17 @@ class Production_orderManager(CommonManager):
     def get_queryset(self):
         return Production_orderQuerySet(self.model, using=self._db)
 
+    @staticmethod
+    def refreshRows(ids):
+        if isinstance(ids, int):
+            ids = [ids]
+        records = [Production_orderManager.getRecord(record) for record in Production_order.objects.filter(id__in=ids)]
+        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_order_grid_row, records=records)
+
+    @staticmethod
+    def fullRows(suffix=''):
+        WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_order_grid}{suffix}')
+
     @staticmethod
     def getRecord(record):
 
@@ -293,8 +300,7 @@ class Production_orderManager(CommonManager):
             'creator__short_name': record.creator.get_short_name,
             'date': record.date,
             'description': record.description,
-            'edizm_id': record.edizm.id,
-            'edizm__name': record.edizm.name,
+            'edizm__name': ' / '.join(record.edizm_arr) if record.edizm_arr != None else None,
             'id': record.id,
             'item_id': record.item.id,
             'parent_item_id': record.parent_item.id if record.parent_item else None,
@@ -383,7 +389,7 @@ class Production_order(Hierarcy):
     status = ForeignKeyProtect(Status_operation_types)
     launch = ForeignKeyProtect(Launches)
     location = ForeignKeyProtect(Locations)
-    edizm = ForeignKeyProtect(Ed_izm)
+    edizm_arr = ArrayField(CodeField(null=True, blank=True))
     item = ForeignKeyProtect(Item, related_name='Production_order_item')
     parent_item = ForeignKeyProtect(Item, null=True, blank=True, related_name='Production_order_parent_item')
 
