@@ -1,11 +1,12 @@
 import logging
 
+from django.conf import settings
 from django.contrib.postgres.fields import ArrayField
 from django.db import transaction
 from django.db.models import DecimalField, DateTimeField, TextField, PositiveIntegerField, SmallIntegerField, BigIntegerField
 from django.db.models.query import EmptyResultSet
 
-from isc_common import delAttr, Wrapper, NotImplement
+from isc_common import delAttr, NotImplement
 from isc_common.auth.models.user import User
 from isc_common.fields.code_field import CodeField
 from isc_common.fields.related import ForeignKeyProtect, ForeignKeySetNull
@@ -13,7 +14,7 @@ from isc_common.http.DSRequest import DSRequest
 from isc_common.managers.common_manager import CommonQuerySet, CommonManager
 from isc_common.models.audit import AuditModel
 from isc_common.number import DelProps, DecimalToStr
-from kaf_pas.ckk.models.ed_izm import Ed_izm
+from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.locations import Locations
 from kaf_pas.ckk.models.locations_users import Locations_users
 from kaf_pas.planing.models.operation_operation import Operation_operation
@@ -50,12 +51,11 @@ class Production_order_opersManager(CommonManager):
         location_ids = [location_user.location.id for location_user in Locations_users.objects.filter(user_id=user)]
         res = {
             # 'location_sector_id': record.location_sector.id,
+            'creator__short_name': record.creator.get_short_name,
             'date': record.date,
             'parent_id': record.parent_id,
             'description': record.description,
-            'edizm__code': record.edizm.code,
-            'edizm__name': record.edizm.name,
-            'edizm_id': record.edizm.id,
+            'edizm__name': ' / '.join(record.edizm_arr) if record.edizm_arr != None else None,
             'enabled': user.is_develop or user.is_admin or record.resource.location.id in location_ids if record.resource else False,
             'id': record.id,
             'launch_id': record.launch.id,
@@ -89,17 +89,24 @@ class Production_order_opersManager(CommonManager):
         }
         return DelProps(res)
 
+    @staticmethod
+    def refreshRows(ids):
+        if isinstance(ids, int):
+            ids = [ids]
+        records = [Production_order_opersManager.getRecord(record) for record in Production_order_opers.objects.filter(id__in=ids)]
+        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_operationsGrid_row, records=records)
+
+    @staticmethod
+    def fullRows(suffix=''):
+        WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_operationsGrid}{suffix}')
+
     def createFromRequest(self, request):
-        from isc_common.common import create
         raise NotImplement()
 
         request = DSRequest(request=request)
         production_ext = Production_ext()
 
-        print(f'data={request.get_data()}')
-
-        data = Wrapper(**request.get_data())
-
+        data = request.get_data()
         production_ext.update_operation(data=data, user=request.user)
 
         return data
@@ -109,10 +116,10 @@ class Production_order_opersManager(CommonManager):
         raise NotImplement()
         ids = request.get_old_ids()
         res = 0
+        production_ext = Production_ext()
 
         with transaction.atomic():
-            for id in ids:
-                print(id)
+            production_ext.delete_operation(ids=ids)
 
         return res
 
@@ -121,11 +128,8 @@ class Production_order_opersManager(CommonManager):
         raise NotImplement()
         production_ext = Production_ext()
 
-        print(f'data={request.get_data()}')
-        print(f'old_data={request.get_oldValues()}')
-
-        data = Wrapper(**request.get_data())
-        old_data = Wrapper(**request.get_oldValues())
+        data = request.get_data()
+        old_data = request.get_oldValues()
 
         return production_ext.update_operation(data=data, old_data=old_data, user=request.user)
 
@@ -154,7 +158,7 @@ class Production_order_opers(AuditModel):
     location = ForeignKeyProtect(Locations, related_name='Production_order_opers_location')
     location_fin = ForeignKeySetNull(Locations, related_name='Production_order_opers_location_fib', null=True, blank=True)
     resource = ForeignKeyProtect(Resource)
-    edizm = ForeignKeyProtect(Ed_izm)
+    edizm_arr = ArrayField(CodeField(null=True, blank=True))
     value_sum = DecimalField(decimal_places=4, max_digits=19)
     value1_sum = ArrayField(DecimalField(decimal_places=4, max_digits=19))
     value_made = DecimalField(decimal_places=4, max_digits=19, null=True, blank=True)
