@@ -31,8 +31,8 @@ class Production_order_per_launchManager(CommonManager):
             'creator__short_name': record.creator.get_short_name,
             'date': record.date,
             'description': record.description,
-            'edizm_id': record.edizm.id,
-            'edizm__name': record.edizm.name,
+            'edizm_id': record.edizm.id if record.edizm else None,
+            'edizm__name': record.edizm.name if record.edizm else None,
             'id': record.id,
             'item_id': record.item.id,
             'parent_item_id': record.parent_item.id if record.parent_item else None,
@@ -85,7 +85,7 @@ class Production_order_per_launch(Hierarcy):
     status = ForeignKeyProtect(Status_operation_types)
     launch = ForeignKeyProtect(Launches)
     location = ForeignKeyProtect(Locations)
-    edizm = ForeignKeyProtect(Ed_izm)
+    edizm = ForeignKeyProtect(Ed_izm, null=True, blank=True)
     cnt_opers = PositiveIntegerField()
 
     item = ForeignKeyProtect(Item, related_name='Production_order_per_launch_item')
