@@ -425,14 +425,13 @@ class Routing_ext:
                                             operation_refs = Operation_refs.objects.create(
                                                 parent=income_operation,
                                                 child=outcome_operation,
-                                                props=Operation_refs.props.inner_routing
+                                                props=Operation_refs.props.inner_routing,
                                             )
                                             logger.debug(f'Created operation_refs :  {operation_refs}')
 
                                             operation_launch_item, created = Operation_launch_item.objects.get_or_create(
                                                 operation=outcome_operation,
                                                 launch_item=launch_operations_item,
-                                                operation_refs=operation_refs,
                                             )
                                             if created:
                                                 logger.debug(f'Created operation_launch_item :  {operation_launch_item}')
@@ -543,8 +542,6 @@ class Routing_ext:
                 qty=launch_operations_material.qty
             )
             operation_materials_set.add(operation_material.id)
-            # todo требует отладки
-            raise NotImplement('update_materials')
         # Удаляем лишние
         Operation_material.objects.filter(operation=new_operation).exclude(id__in=list(operation_materials_set)).delete()
 
@@ -607,7 +604,8 @@ class Routing_ext:
             parents_rows = cursor.fetchall()
             for row in parents_rows:
                 parent_ids, id, operation_id, num, prod_operation_id, child_ids = row
-                logger.debug(f'parent_ids: {parent_ids}, id: {id}, operation_id: {operation_id}, num: {num}, prod_operation_id: {prod_operation_id}, child_ids: {child_ids}')
+                print(f'parent_ids: {parent_ids}, id: {id}, operation_id: {operation_id}, num: {num}, prod_operation_id: {prod_operation_id}, child_ids: {child_ids}')
+                # logger.debug(f'parent_ids: {parent_ids}, id: {id}, operation_id: {operation_id}, num: {num}, prod_operation_id: {prod_operation_id}, child_ids: {child_ids}')
 
     def get_parents(self, operation):
         from kaf_pas.planing.models.operation_refs import Operation_refs
@@ -622,6 +620,8 @@ class Routing_ext:
         from kaf_pas.planing.operation_typesStack import RT_TSK
 
         childs = [a.child.id for a in Operation_refs.objects.filter(parent=operation, child__opertype__code=RT_TSK, deleted_at__isnull=False)]
+        if len(childs) == 0:
+            childs = [a.child.id for a in Operation_refs.objects.filter(parent=operation, child__opertype__code=RT_TSK, deleted_at__isnull=True)]
         logger.debug(f'childs: {childs}')
         return childs
 
@@ -652,7 +652,7 @@ class Routing_ext:
         logger.debug(f'operation: {operation}')
         return operation
 
-    def change_parent(self, new_parents, operation):
+    def change_parent(self, new_parents, operation,user):
         from kaf_pas.planing.models.operation_refs import Operation_refs
         from kaf_pas.planing.operation_typesStack import RT_TSK
 
@@ -671,7 +671,7 @@ class Routing_ext:
                         operation_ref.deleted_at = None
                         operation_ref.save()
 
-    def change_childs(self, new_childs, operation):
+    def change_childs(self, new_childs, operation, user):
         from kaf_pas.planing.models.operation_refs import Operation_refs
         from kaf_pas.planing.operation_typesStack import RT_TSK
 
@@ -690,7 +690,7 @@ class Routing_ext:
                         operation_ref.deleted_at = None
                         operation_ref.save()
 
-    def update_routing(self, data, old_data, updated_launch_operations_items: Stack):
+    def update_routing(self, data, old_data, updated_launch_operations_items: Stack, user, key=None):
         from kaf_pas.planing.models.operation_launch_item import Operation_launch_item
 
         logger.debug(f'num: {data.production_operation_num}')
@@ -707,6 +707,7 @@ class Routing_ext:
 
             step = 1
 
+            been_is_created = False
             for updated_launch_operations_item in lst:
 
                 # if step == 1:
@@ -719,7 +720,7 @@ class Routing_ext:
                 self.update_materials(updated_launch_operations_item=updated_launch_operations_item, new_operation=new_operation)
                 self.update_resources(updated_launch_operations_item=updated_launch_operations_item, new_operation=new_operation)
 
-                if updated_launch_operations_item.num == updated_launch_operations_item.old_num:
+                if updated_launch_operations_item.num == updated_launch_operations_item.old_num and not updated_launch_operations_item.is_created:
                     step += 1
                     # if step >= max_num:
                     #     self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
@@ -727,6 +728,8 @@ class Routing_ext:
 
                 logger.debug(f'updated_launch_operations_item.num: {updated_launch_operations_item.num}')
                 logger.debug(f'updated_launch_operations_item.old_num: {updated_launch_operations_item.old_num}')
+                if not been_is_created:
+                    been_is_created = updated_launch_operations_item.is_created
 
                 if updated_launch_operations_item.num == 1:
                     if data.production_operation_num < old_data.production_operation_num:
@@ -750,15 +753,23 @@ class Routing_ext:
                     )
                     parents = [prev_num_operation.id]
                 logger.debug(f'prev_num_operation: {prev_num_operation}')
-                self.change_parent(new_parents=parents, operation=new_operation)
+                self.change_parent(new_parents=parents, operation=new_operation, user=user)
                 # parents = self.get_parents(operation=new_operation)
 
                 if updated_launch_operations_item.num == max_num:
-                    next_num_operation = self.get_num_operation(
-                        launch=updated_launch_operations_item.launch,
-                        item=updated_launch_operations_item.item,
-                        old_num=updated_launch_operations_item.num  # Правильно, не  менять
-                    )
+                    if not been_is_created:
+                        next_num_operation = self.get_num_operation(
+                            launch=updated_launch_operations_item.launch,
+                            item=updated_launch_operations_item.item,
+                            old_num=updated_launch_operations_item.num  # Правильно, не  менять !!!
+                        )
+                    else:
+                        next_num_operation = self.get_num_operation(
+                            launch=updated_launch_operations_item.launch,
+                            item=updated_launch_operations_item.item,
+                            num=updated_launch_operations_item.num  # Правильно, не  менять !!!
+                        )
+
                     childs = self.get_childs(operation=next_num_operation)
                 else:
                     next_num_operation = self.get_num_operation(
@@ -768,11 +779,12 @@ class Routing_ext:
                     )
                     childs = [next_num_operation.id]
                 logger.debug(f'next_num_operation: {next_num_operation}')
-                self.change_childs(new_childs=childs, operation=new_operation)
+                self.change_childs(new_childs=childs, operation=new_operation, user=user)
                 # childs = self.get_childs(operation=new_operation)
 
-                # if step >= max_num:
-                #     self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
+                if step >= max_num:
+                    pass
+                    # self.print_operation_block(launch_id=launch_id, item_id=updated_launch_operations_item.item_id)
                 step += 1
 
     def clean_routing(self, data):
