@@ -2,49 +2,63 @@ import logging
 
 from django.forms import model_to_dict
 
+from isc_common import setAttr
 from isc_common.http.DSRequest import DSRequest
-from kaf_pas.ckk.models.locations import Locations
-from kaf_pas.planing.models.operation_level_view import Operation_level_view
-from kaf_pas.planing.models.operation_location_view import Operation_location_view
-from kaf_pas.planing.models.operation_resources_view import Operation_resources_view
+from isc_common.number import DelProps
 from kaf_pas.planing.models.operations_rout_view import Operations_rout_viewManager
 from kaf_pas.planing.models.operations_view import Operations_view, Operations_viewManager, Operations_viewQuerySet
+from kaf_pas.planing.models.rouning_ext import Routing_ext
 
 logger = logging.getLogger(__name__)
 
 
+class Launch_items:
+    def __init__(self, row):
+        from kaf_pas.ckk.models.item import Item
+
+        self.id, self.parent_id, self.child_id, self.launch_id, self.qty, self.replication_factor, self.qty_per_one, self.edizm_id, self.level, self.item_full_name, self.item_full_name_obj = row
+
+        self.child = Item.objects.get(id=self.child_id)
+        self.parent = Item.objects.get(id=self.parent_id) if self.parent_id else None
+        # self.level = Levels.objects.get(code=self.level)
+
+    def __str__(self):
+        return f'child: [{self.child}], \n' \
+               f'level: [{self.level}]'
+
+
 class RoutingQuerySet(Operations_viewQuerySet):
     def raw(self, raw_query=None, params=None, translations=None, using=None, function=None):
         if raw_query == None:
             raw_query = '''select *
-                            from (with r as (select          pr."id",
-                                                             pr."child_id",
-                                                             null::bigint "parent_id",
-                                                             pr."num",
-                                                             pr."date",
-                                                             pr."deleted_at",
-                                                             pr."editing",
-                                                             pr."deliting",
-                                                             pr."lastmodified",
-                                                             pr."opertype_id",
-                                                             pr."STMP_1_id",
-                                                             pr."item__STMP_1_value_str",
-                                                             pr."STMP_2_id",
-                                                             pr."item__STMP_2_value_str",
-                                                             pr."status_id",
-                                                             pr."description",
-                                                             pr."creator_id",
-                                                             pr."resource_id",
-                                                             pr."item_id",
-                                                             pr."level_id",
-                                                             pr."launch_id",
-                                                             pr."location_id",
-                                                             0 as         "props",
-                                                             pr."production_operation_id",
-                                                             pr."production_operation_ed_izm_id",
-                                                             pr."production_operation_num",
-                                                             pr."production_operation_qty",
-                                                             pr."mark"
+                            from (with r as (select  pr."id",
+                                                     pr."child_id",
+                                                     null::bigint "parent_id",
+                                                     pr."num",
+                                                     pr."date",
+                                                     pr."deleted_at",
+                                                     pr."editing",
+                                                     pr."deliting",
+                                                     pr."lastmodified",
+                                                     pr."opertype_id",
+                                                     pr."STMP_1_id",
+                                                     pr."item__STMP_1_value_str",
+                                                     pr."STMP_2_id",
+                                                     pr."item__STMP_2_value_str",
+                                                     pr."status_id",
+                                                     pr."description",
+                                                     pr."creator_id",
+                                                     pr."resource_id",
+                                                     pr."item_id",
+                                                     pr."level_id",
+                                                     pr."launch_id",
+                                                     pr."location_id",
+                                                     0 as         "props",
+                                                     pr."production_operation_id",
+                                                     pr."production_operation_ed_izm_id",
+                                                     pr."production_operation_num",
+                                                     pr."production_operation_qty",
+                                                     pr."mark"
                                              from planing_operation_rout_view pr
                                              where pr.item_id = %s      --0
                                                and pr.resource_id = %s --1
@@ -184,6 +198,7 @@ class RoutingQuerySet(Operations_viewQuerySet):
 
 
 class RoutingManager(Operations_viewManager):
+    routing_ext = Routing_ext()
 
     @staticmethod
     def getRecord(record):
@@ -196,96 +211,40 @@ class RoutingManager(Operations_viewManager):
         request = DSRequest(request=request)
 
         launch_id = request.get_data().get('launch_id')
-        levels = RoutingManager.make_levels(launch_id=launch_id)
+        levels = self.routing_ext.make_levels(launch_id=launch_id)
         return levels
 
-    @staticmethod
-    def make_levels(launch_id):
-        res = [
-            dict(
-                id=operation.get('level_id'),
-                title=operation.get('level__name'),
-                prompt=f'''ID: {operation.get('level_id')}, {operation.get('level__code')} : {operation.get('level__name')}'''
-            )
-            for operation in Operation_level_view.objects.
-                filter(
-                launch_id=launch_id,
-                opers_refs_props__in=[
-                    Operations_view.props.inner_routing,
-                    Operations_view.props.outer_routing,
-                ]
-            ).
-                order_by('level__code').
-                values('level_id', 'level__name', 'level__code').
-                distinct()
-        ]
-        return res
-
     def fetchLocationsLevelFromRequest(self, request):
         request = DSRequest(request=request)
 
         launch_id = request.get_data().get('launch_id')
         level_id = request.get_data().get('level_id')
-        levels = RoutingManager.make_locationsLevel(launch_id=launch_id, level_id=level_id)
+        levels = self.routing_ext.make_locationsLevel(launch_id=launch_id, level_id=level_id)
         return levels
 
-    @staticmethod
-    def make_locationsLevel(launch_id, level_id):
-        res = sorted([
-            dict(
-                id=operation.get('location_id'),
-                title=Locations.objects.get(id=operation.get('location_id')).full_name,
-                prompt=f'''ID: {operation.get('location_id')}''',
-            )
-            for operation in Operation_location_view.objects.
-                filter(
-                launch_id=launch_id,
-                opers_refs_props__in=[
-                    Operations_view.props.inner_routing,
-                    Operations_view.props.outer_routing,
-                ],
-                level_id=level_id
-            ).
-                values('location_id', 'location__name').
-                distinct()
-        ],
-            key=lambda x: x['title'])
-
-        return res
-
     def fetchResourcesLevelFromRequest(self, request):
         request = DSRequest(request=request)
 
         launch_id = request.get_data().get('launch_id')
         level_id = request.get_data().get('level_id')
         location_id = request.get_data().get('location_id')
-        levels = RoutingManager.make_resourcesLevel(launch_id=launch_id, level_id=level_id, location_id=location_id)
+        levels = self.routing_ext.make_resourcesLevel(launch_id=launch_id, level_id=level_id, location_id=location_id)
         return levels
 
-    @staticmethod
-    def make_resourcesLevel(launch_id, level_id, location_id):
-        res = sorted([
-            dict(
-                id=operation.get('resource_id'),
-                title=operation.get('resource__name'),
-                prompt=f'''ID: {operation.get('resource_id')}, {operation.get('resource__description')}''',
-            )
-            for operation in Operation_resources_view.objects.
-                filter(
-                launch_id=launch_id,
-                level_id=level_id,
-                location_id=location_id,
-                props__in=[
-                    Operations_view.props.inner_routing,
-                    Operations_view.props.outer_routing,
-                ],
-            ).
-                values('resource_id', 'resource__name', 'resource__description').
-                distinct()
-        ],
-            key=lambda x: x['title'])
+    def cleanRoutesFromRequest(self, request):
+        request = DSRequest(request=request)
+        data = request.get_data()
+        setAttr(data, 'user', request.user)
+        res = self.routing_ext.clean_routing(data=data)
+        return DelProps(res)
 
-        return res
+    def reCalcRoutesFromRequest(self, request):
+        request = DSRequest(request=request)
+        data = request.get_data()
+        _data = data.copy()
+        setAttr(_data, 'user', request.user)
+        self.routing_ext.make_routing(data=_data)
+        return data
 
 
 class Routing(Operations_view):
