@@ -28,13 +28,13 @@ def Production_order_Fetch(request):
             DSResponse(
                 request=request,
                 data=Production_order.objects.
-                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'edizm', 'item').
+                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'item').
                     filter(opertype__in=opers_types).
                     get_range_rows1(
                     request=request,
                     function=Production_orderManager.getRecord
                 ) if arranged == False else Production_order.objects.
-                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'edizm', 'item').
+                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'item').
                     filter(opertype__in=opers_types).
                     filter(arranges_exucutors__overlap=[_request.user_id]).
                     get_range_rows1(
@@ -47,14 +47,14 @@ def Production_order_Fetch(request):
             DSResponse(
                 request=request,
                 data=Production_order.objects.
-                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'edizm', 'item').
+                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'item').
                     filter(opertype__in=opers_types).
                     filter(exucutors__overlap=[_request.user_id]).
                     get_range_rows1(
                     request=request,
                     function=Production_orderManager.getRecord
                 ) if arranged == False else Production_order.objects.
-                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'edizm', 'item').
+                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'item').
                     filter(opertype__in=opers_types).
                     filter(arranges_exucutors__overlap=[_request.user_id]).
                     get_range_rows1(
@@ -77,7 +77,7 @@ def Production_order_per_launch_Fetch(request):
             DSResponse(
                 request=request,
                 data=Production_order_per_launch.objects.
-                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'edizm', 'item').
+                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'item').
                     filter(
                     opertype__in=opers_types,
                 ).
@@ -91,7 +91,7 @@ def Production_order_per_launch_Fetch(request):
             DSResponse(
                 request=request,
                 data=Production_order_per_launch.objects.
-                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'edizm', 'item').
+                    select_related('opertype', 'creator', 'status', 'launch', 'location', 'item').
                     filter(
                     opertype__in=opers_types,
                 ).
