@@ -4,6 +4,7 @@ from django.core.management import BaseCommand
 
 from isc_common import setAttr
 from kaf_pas.production.models.launches import LaunchesManager
+from kaf_pas.production.models.launches_ext import Launches_ext
 
 logger = logging.getLogger(__name__)
 
@@ -22,6 +23,7 @@ class Command(BaseCommand):
         setAttr(data, 'user_id', user_id)
         print(f'data: {data}')
 
-        LaunchesManager.make_launch(data=data)
+        launches_ext = Launches_ext()
+        launches_ext.make_launch(data=data)
 
         print('Done')
