@@ -3,7 +3,6 @@ import logging
 from django.core.management import BaseCommand
 
 from isc_common import setAttr
-from kaf_pas.production.models.launches import LaunchesManager
 
 logger = logging.getLogger(__name__)
 
@@ -21,6 +20,6 @@ class Command(BaseCommand):
         user_id = options.get('user_id')
         setAttr(data, 'user_id', user_id)
 
-        LaunchesManager.update_launch(data=data)
+        # LaunchesManager.update_launch(data=data)
 
         print('Done')
