@@ -214,6 +214,14 @@ class Launch_operations_item(Hierarcy):
     def __repr__(self):
         return self.operation.full_name
 
+    @property
+    def is_created(self):
+        return self.props._value == Launch_operations_item.props.created
+
+    @property
+    def is_updated(self):
+        return self.props._value == Launch_operations_item.props.updated
+
     class Meta:
         verbose_name = 'Кросс таблица'
         unique_together = (('item', 'launch', 'operation', 'num', 'operationitem'),)
