@@ -116,6 +116,124 @@ class Launches_ext:
         settings.LOCKS.release(key)
         return res
 
+    def rec_operation(self, operations_item, launch, get_full_path):
+        from django.conf import settings
+        from isc_common.common import blinkString
+        from kaf_pas.production.models.launch_operation_attr import Launch_operation_attr
+        from kaf_pas.production.models.launch_operation_material import Launch_operations_material
+        from kaf_pas.production.models.launch_operation_resources import Launch_operation_resources
+        from kaf_pas.production.models.launch_operations_item import Launch_operations_item
+        from kaf_pas.production.models.operation_attr import Operation_attr
+        from kaf_pas.production.models.operation_material import Operation_material
+        from kaf_pas.production.models.operation_resources import Operation_resources
+
+        # start_time = time.clock()
+        launch_operations_item, created = Launch_operations_item.objects.get_or_create(
+            item=operations_item.item,
+            launch=launch,
+            num=operations_item.num,
+            operation=operations_item.operation,
+            defaults=dict(
+                description=operations_item.description,
+                ed_izm=operations_item.ed_izm,
+                operationitem=operations_item,
+                qty=operations_item.qty,
+            )
+        )
+
+        for operation_attr in Operation_attr.objects.filter(operation=operations_item.operation):
+            Launch_operation_attr.objects.get_or_create(
+                operation=launch_operations_item.operation,
+                launch=launch,
+                attr_type=operation_attr.attr_type
+            )
+
+        if created:
+            logger.debug(f'Created: {created} launch_operations_item :  {launch_operations_item}')
+            # logger_timing.debug(f'launch_operations_item Time: {time.clock() - start_time}')
+
+            operation_material_query = Operation_material.objects.filter(operationitem=operations_item)
+
+            for operation_material in operation_material_query:
+                # start_time = time.clock()
+                # 'launch_operationitem', 'material', 'material_askon'
+                if operation_material.material != None or operation_material.material_askon != None:
+                    launch_operations_material, created = Launch_operations_material.objects.get_or_create(
+                        launch_operationitem=launch_operations_item,
+                        material=operation_material.material,
+                        material_askon=operation_material.material_askon,
+                        defaults=dict(
+                            operation_material=operation_material,
+                            edizm=operation_material.edizm,
+                            qty=operation_material.qty,
+                        )
+                    )
+                    # launch_operations_materials.push(launch_operations_material)
+                    if created:
+                        logger.debug(f'Created: launch_operations_material :  {launch_operations_material}')
+
+            def exception_not_location():
+                raise Exception(f'''<b>Для : {get_full_path}</b>  {blinkString(text='не задано местоположение. Запустите анализатор готовности к запуску.', blink=False, color='red', bold=True)}''')
+
+            operation_resources_query = Operation_resources.objects.filter(operationitem=operations_item)
+
+            if operation_resources_query.count() == 0:
+                exception_not_location()
+
+            for operation_resources in operation_resources_query:
+                if operation_resources.location == None:
+                    exception_not_location()
+
+                if operation_resources.resource == None:
+                    # start_time = time.clock()
+                    operation_resources.resource, created = settings.OPERS_STACK.NOT_UNDEFINED_WORKSHOP(operation_resources.location)
+                    # logger.debug(f'Created : {created} operation_resources.resource :  {operation_resources.resource}')
+                    # logger_timing.debug(f'Resource.objects.get_or_create Time: {time.clock() - start_time}')
+
+                # start_time = time.clock()
+                # 'launch_operationitem', 'location', 'resource'
+                launch_operation_resource, created = Launch_operation_resources.objects.get_or_create(
+                    launch_operationitem=launch_operations_item,
+                    resource=operation_resources.resource,
+                    location=operation_resources.location,
+                    location_fin=operation_resources.location_fin,
+                    defaults=dict(
+                        operation_resources=operation_resources,
+                        batch_size=operation_resources.batch_size,
+                    )
+                )
+                # launch_operation_resources.push(launch_operation_resource)
+                if created:
+                    logger.debug(f'Created: launch_operation_resources.resource :  {launch_operation_resource}')
+
+    def rec_operations_data(self, item, section, get_full_path, key, first_step, launch):
+        from django.conf import settings
+        from isc_common.common import blinkString
+        from kaf_pas.production.models.operations_item import Operations_item
+
+        # start_time = time.clock()
+        cnt = Operations_item.objects.filter(item=item).count()
+        # logger_timing.debug(f'Operations_item.objects.filter Time: {time.clock() - start_time}')
+        if cnt == 0:
+            if section != 'Документация':
+                settings.LOCKS.release(key)
+                raise Exception(blinkString(text=f'Для : ID: {item.id} {get_full_path} не найдена операция.', bold=True, blink=False))
+        else:
+
+            if first_step == True and section == 'Документация':
+                settings.LOCKS.release(key)
+                raise Exception(blinkString(text=f'Изделие : ID: {item.id} {get_full_path} должно входить как сборочная еденица.', bold=True, blink=False))
+
+            if section != 'Документация':
+                operations_item_query = Operations_item.objects.filter(item=item)
+
+                for operations_item in operations_item_query:
+                    try:
+                        self.rec_operation(operations_item=operations_item, launch=launch, get_full_path=get_full_path)
+                    except Exception as ex:
+                        settings.LOCKS.release(key)
+                        raise ex
+
     def make_launch(self, data, mode='add'):
         from django.conf import settings
         from django.db import transaction
@@ -137,15 +255,7 @@ class Launches_ext:
         from kaf_pas.production.models import p_id
         from kaf_pas.production.models.launch_item_line import Launch_item_line
         from kaf_pas.production.models.launch_item_refs import Launch_item_refs
-        from kaf_pas.production.models.launch_operation_attr import Launch_operation_attr
-        from kaf_pas.production.models.launch_operation_material import Launch_operations_material
-        from kaf_pas.production.models.launch_operation_resources import Launch_operation_resources
-        from kaf_pas.production.models.launch_operations_item import Launch_operations_item
         from kaf_pas.production.models.launches import Launches
-        from kaf_pas.production.models.operation_attr import Operation_attr
-        from kaf_pas.production.models.operation_material import Operation_material
-        from kaf_pas.production.models.operation_resources import Operation_resources
-        from kaf_pas.production.models.operations_item import Operations_item
         from kaf_pas.production.models.ready_2_launch_ext import Item_refs_Stack
         from kaf_pas.sales.models.demand import Demand
         from kaf_pas.sales.models.demand_view import Demand_view
@@ -352,124 +462,26 @@ class Launches_ext:
 
                                 if created:
                                     logger.debug(f'Created : launch_item_line :  {launch_item_line}')
-                                else:
-                                    pass
-                                    # logger.warning(f'!!!!!!!!!!!!!!!!!!!!!!!!!!!! Not Created: {created} launch_item_line :  {launch_item_line} !!!!!!!!!!!!!!!!!!!!!!!')
-
-                                # logger_timing.debug(f'launch_item_line Time: {time.clock() - start_time}')
-
-                                def rec_operations_data(item, item_ref, launch_item_line, get_full_path):
-                                    # start_time = time.clock()
-                                    cnt = Operations_item.objects.filter(item=item).count()
-                                    # logger_timing.debug(f'Operations_item.objects.filter Time: {time.clock() - start_time}')
-                                    if cnt == 0:
-                                        if item_line.section != 'Документация':
-                                            settings.LOCKS.release(key)
-                                            raise Exception(blinkString(text=f'Для : ID: {item.id} {get_full_path} не найдена операция.', bold=True, blink=False))
-                                    else:
-                                        section = launch_item_line.section
-
-                                        if first_step == True and section and section == 'Документация':
-                                            settings.LOCKS.release(key)
-                                            raise Exception(blinkString(text=f'Изделие : ID: {item.id} {get_full_path} должно входить как сборочная еденица.', bold=True, blink=False))
-
-                                        if section and section != 'Документация':
-                                            operations_item_query = Operations_item.objects.filter(item=item)
-
-                                            for operations_item in operations_item_query:
-                                                # start_time = time.clock()
-                                                launch_operations_item, created = Launch_operations_item.objects.get_or_create(
-                                                    item=operations_item.item,
-                                                    launch=launch,
-                                                    num=operations_item.num,
-                                                    operation=operations_item.operation,
-                                                    defaults=dict(
-                                                        description=operations_item.description,
-                                                        ed_izm=operations_item.ed_izm,
-                                                        operationitem=operations_item,
-                                                        qty=operations_item.qty,
-                                                    )
-                                                )
-
-                                                for operation_attr in Operation_attr.objects.filter(operation=operations_item.operation):
-                                                    Launch_operation_attr.objects.get_or_create(
-                                                        operation=launch_operations_item.operation,
-                                                        launch=launch,
-                                                        attr_type=operation_attr.attr_type
-                                                    )
-
-                                                if created:
-                                                    logger.debug(f'Created: {created} launch_operations_item :  {launch_operations_item}')
-                                                    # logger_timing.debug(f'launch_operations_item Time: {time.clock() - start_time}')
-
-                                                    operation_material_query = Operation_material.objects.filter(operationitem=operations_item)
-
-                                                    for operation_material in operation_material_query:
-                                                        # start_time = time.clock()
-                                                        # 'launch_operationitem', 'material', 'material_askon'
-                                                        if operation_material.material != None or operation_material.material_askon != None:
-                                                            launch_operations_material, created = Launch_operations_material.objects.get_or_create(
-                                                                launch_operationitem=launch_operations_item,
-                                                                material=operation_material.material,
-                                                                material_askon=operation_material.material_askon,
-                                                                defaults=dict(
-                                                                    operation_material=operation_material,
-                                                                    edizm=operation_material.edizm,
-                                                                    qty=operation_material.qty,
-                                                                )
-                                                            )
-                                                            # launch_operations_materials.push(launch_operations_material)
-                                                            if created:
-                                                                logger.debug(f'Created: launch_operations_material :  {launch_operations_material}')
-                                                            else:
-                                                                logger.warning(f'!!!!!!!!!!!!!!!!!!!!!!!!!!!! Not Created: {created} launch_operations_material :  {launch_operations_material} !!!!!!!!!!!!!!!!!!!!!!!')
-                                                                # logger_timing.debug(f'launch_operations_material Time: {time.clock() - start_time}')
-
-                                                    def exception_not_location():
-                                                        settings.LOCKS.release(key)
-                                                        raise Exception(f'''<b>Для : {items_refs_stack.get_full_path}</b>  {blinkString(text='не задано местоположение. Запустите анализатор готовности к запуску.', blink=False, color='red', bold=True)}''')
-
-                                                    operation_resources_query = Operation_resources.objects.filter(operationitem=operations_item)
-
-                                                    if operation_resources_query.count() == 0:
-                                                        exception_not_location()
-
-                                                    for operation_resources in operation_resources_query:
-                                                        if operation_resources.location == None:
-                                                            exception_not_location()
-
-                                                        if operation_resources.resource == None:
-                                                            # start_time = time.clock()
-                                                            operation_resources.resource, created = settings.OPERS_STACK.NOT_UNDEFINED_WORKSHOP(operation_resources.location)
-                                                            # logger.debug(f'Created : {created} operation_resources.resource :  {operation_resources.resource}')
-                                                            # logger_timing.debug(f'Resource.objects.get_or_create Time: {time.clock() - start_time}')
-
-                                                        # start_time = time.clock()
-                                                        # 'launch_operationitem', 'location', 'resource'
-                                                        launch_operation_resource, created = Launch_operation_resources.objects.get_or_create(
-                                                            launch_operationitem=launch_operations_item,
-                                                            resource=operation_resources.resource,
-                                                            location=operation_resources.location,
-                                                            location_fin=operation_resources.location_fin,
-                                                            defaults=dict(
-                                                                operation_resources=operation_resources,
-                                                                batch_size=operation_resources.batch_size,
-                                                            )
-                                                        )
-                                                        # launch_operation_resources.push(launch_operation_resource)
-                                                        if created:
-                                                            logger.debug(f'Created: launch_operation_resources.resource :  {launch_operation_resource}')
-                                                        else:
-                                                            logger.warning(f'!!!!!!!!!!!!!!!!!!!!!!!!!!!! Not Created: {created} launch_operation_resources :  {launch_operation_resource} !!!!!!!!!!!!!!!!!!!!!!!')
-                                                            # logger_timing.debug(f'Launch_operation_resources.objects.get_or_create Time: {time.clock() - start_time}')
-                                                else:
-                                                    pass
-                                                    # logger.debug(f'!!!!!!!!!!!!!!!!!!!!!!!!!!!! Not Created: {created} launch_item_refs :  {launch_operations_item} !!!!!!!!!!!!!!!!!!!!!!!')
 
                                 if item_ref.parent:
                                     if first_step == False:
-                                        rec_operations_data(item=item_ref.parent, item_ref=item_ref, launch_item_line=launch_item_line, get_full_path=items_refs_stack.get_full_path)
-                                rec_operations_data(item=item_ref.child, item_ref=item_ref, launch_item_line=launch_item_line, get_full_path=items_refs_stack.get_full_path)
+                                        self.rec_operations_data(
+                                            item=item_ref.parent,
+                                            section=launch_item_line.section,
+                                            get_full_path=items_refs_stack.get_full_path,
+                                            key=key,
+                                            first_step=first_step,
+                                            launch=launch,
+                                        )
+
+                                self.rec_operations_data(
+                                    item=item_ref.child,
+                                    section=launch_item_line.section,
+                                    get_full_path=items_refs_stack.get_full_path,
+                                    key=key,
+                                    first_step=first_step,
+                                    launch=launch,
+                                )
                                 first_step = False
 
                                 if progress.step() != 0:
