@@ -1,10 +1,12 @@
 import logging
 
+from django.conf import settings
 from django.db.models import DateTimeField, BooleanField, DecimalField, PositiveIntegerField
 
 from isc_common.fields.related import ForeignKeyProtect
 from isc_common.models.base_ref import BaseRefHierarcy, BaseRefManager, BaseRefQuerySet
-from isc_common.number import DelProps, DecimalToStr
+from isc_common.number import DelProps, DecimalToStr, ToDecimal
+from isc_common.ws.webSocket import WebSocket
 from kaf_pas.ckk.models.item import Item
 from kaf_pas.production.models.status_launch import Status_launch
 from kaf_pas.sales.models.demand import Demand
@@ -18,8 +20,21 @@ class Launches_viewQuerySet(BaseRefQuerySet):
 
 class Launches_viewManager(BaseRefManager):
 
+    @staticmethod
+    def refreshRows(ids):
+        if isinstance(ids, int):
+            ids = [ids]
+        records = [Launches_viewManager.getRecord(record) for record in Launches_view.objects.filter(id__in=ids)]
+        WebSocket.row_refresh_grid(grid_id=settings.GRID_CONSTANTS.refresh_production_launch_grid_row, records=records)
+
+    @staticmethod
+    def fullRows(suffix=''):
+        WebSocket.full_refresh_grid(grid_id=f'{settings.GRID_CONSTANTS.refresh_production_launch_grid}{suffix}')
+
     @staticmethod
     def getRecord(record):
+        from isc_common.managers.common_manager import CommonManager
+
         res = {
             'id': record.id,
             'code': record.code,
@@ -55,7 +70,9 @@ class Launches_viewManager(BaseRefManager):
             'editing': record.editing,
             'deliting': record.deliting,
         }
-        return DelProps(res)
+        res = DelProps(res)
+        # print(res)
+        return res
 
     def get_queryset(self):
         return Launches_viewQuerySet(self.model, using=self._db)
