@@ -13,11 +13,12 @@ from kaf_pas.production.models.launches import Launches
 
 @JsonResponseWithException()
 def Launch_operations_item_Fetch(request):
+    _request = DSRequest(request)
     return JsonResponse(
         DSResponse(
             request=request,
             data=Launch_operations_item.objects.
-                filter().
+                select_related('item', 'operation', 'ed_izm', 'launch', 'operation', 'operationitem').
                 get_range_rows1(
                 request=request,
                 function=Launch_operations_itemManager.getRecord
