@@ -29,11 +29,6 @@ def Launches_Update(request):
     return JsonResponse(DSResponseUpdate(data=Launches.objects.updateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
 
 
-@JsonWSResponseWithException()
-def Launches_ReCreate(request):
-    return JsonResponse(DSResponseUpdate(data=Launches.objects.reCreateFromRequest(request), status=RPCResponseConstant.statusSuccess).response)
-
-
 @JsonWSResponseWithException()
 def Launches_Remove(request):
     return JsonResponse(DSResponse(request=request, data=Launches.objects.deleteFromRequest(request=request), status=RPCResponseConstant.statusSuccess).response)
